==> haskell-aeson-2.1.2.1-182.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson
version:              2.1.2.1
visibility:           public
id:                   aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
key:                  aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  ed500ba9fe66537a85c17ed504a113c6
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Decoding Data.Aeson.Decoding.ByteString
    Data.Aeson.Decoding.ByteString.Lazy Data.Aeson.Decoding.Tokens
    Data.Aeson.Encoding Data.Aeson.Encoding.Internal
    Data.Aeson.Internal Data.Aeson.Internal.Time Data.Aeson.Key
    Data.Aeson.KeyMap Data.Aeson.Parser Data.Aeson.Parser.Internal
    Data.Aeson.QQ.Simple Data.Aeson.TH Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Decoding.Internal Data.Aeson.Encoding.Builder
    Data.Aeson.Internal.ByteString Data.Aeson.Internal.Functions
    Data.Aeson.Internal.Integer Data.Aeson.Internal.Text
    Data.Aeson.Internal.TH Data.Aeson.Internal.Word8
    Data.Aeson.Parser.Time Data.Aeson.Parser.Unescape
    Data.Aeson.Types.Class Data.Aeson.Types.FromJSON
    Data.Aeson.Types.Generic Data.Aeson.Types.Internal
    Data.Aeson.Types.ToJSON Data.Attoparsec.Time
    Data.Attoparsec.Time.Internal Data.Aeson.Parser.UnescapePure

import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-2.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-2.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-2.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson
hs-libraries:         HSaeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
depends:
    OneTuple-0.4.2-6h1VpY4iGdO6wZSCEFOMPx
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    base-compat-batteries-0.14.1-lgVr2peCDw5qXG4VLbklv
    bytestring-0.11.5.3 containers-0.6.7
    data-fix-0.3.4-DcHJ3ttKSJw5ofwAk9Vr2A deepseq-1.4.8.1
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO exceptions-0.10.7
    generically-0.1.1-I9byc5Nil798plofO827gA ghc-prim-0.10.0
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV
    semialign-1.3.1-H4mxDRs3fr5J5cBeCN8OlQ
    strict-0.5.1-Kvxonrthq62FwakQ5ElNMl
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    text-2.0.2 text-short-0.1.6-LT3hLgE3AIH5LX66Bu59Xl
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH
    these-1.2.1-FiiqKcU92mLD4q4YanLE50 time-1.12.2
    time-compat-1.9.8-KXBZmSgVcbpGOqrx2hUfcV
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    uuid-types-1.0.6-58FfeLal0FhHrTZjsfHNqD
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    witherable-0.4.2-8vp6m8pf3M0Augnf8mmIUp

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-2.1.2.1-183-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson
version:              2.1.2.1
visibility:           public
id:                   aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
key:                  aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  1a99bac59b62599983e7e9e08498ebaf
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Decoding Data.Aeson.Decoding.ByteString
    Data.Aeson.Decoding.ByteString.Lazy Data.Aeson.Decoding.Tokens
    Data.Aeson.Encoding Data.Aeson.Encoding.Internal
    Data.Aeson.Internal Data.Aeson.Internal.Time Data.Aeson.Key
    Data.Aeson.KeyMap Data.Aeson.Parser Data.Aeson.Parser.Internal
    Data.Aeson.QQ.Simple Data.Aeson.TH Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Decoding.Internal Data.Aeson.Encoding.Builder
    Data.Aeson.Internal.ByteString Data.Aeson.Internal.Functions
    Data.Aeson.Internal.Integer Data.Aeson.Internal.Text
    Data.Aeson.Internal.TH Data.Aeson.Internal.Word8
    Data.Aeson.Parser.Time Data.Aeson.Parser.Unescape
    Data.Aeson.Types.Class Data.Aeson.Types.FromJSON
    Data.Aeson.Types.Generic Data.Aeson.Types.Internal
    Data.Aeson.Types.ToJSON Data.Attoparsec.Time
    Data.Attoparsec.Time.Internal Data.Aeson.Parser.UnescapePure

import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-2.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-2.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-2.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson
hs-libraries:         HSaeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
depends:
    OneTuple-0.4.2-6pEN3mXYu4CEsP59PDdiWd
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base-compat-batteries-0.14.1-7XhCMBTAbUaB4cukby3R0h
    bytestring-0.11.5.3 containers-0.6.7
    data-fix-0.3.4-3won58iaWYcBjetskLCnc9 deepseq-1.4.8.1
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO exceptions-0.10.7
    generically-0.1.1-I9byc5Nil798plofO827gA ghc-prim-0.10.0
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW
    semialign-1.3.1-ds4uro8cXRHYHfeRBsHPF
    strict-0.5.1-FbuUXvHHt04IVZ1UpYOqLR
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    text-2.0.2 text-short-0.1.6-uDJBdqgRh39kcxwO1KbRc
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH
    these-1.2.1-FFxH0GxUZUDAtgQSChMM1W time-1.12.2
    time-compat-1.9.8-ITy6Cf33IaSAWRM66COV33
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    uuid-types-1.0.6-21TzNsexUnW19QIZkyQGNe
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    witherable-0.4.2-FFlKR43IlesAoDsuuCtTMQ

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
